==> xtide_2.6.4.orig.tar.gz: xtide-2.6.4/tcd-utils/version.h <==

/*****************************************************************************\

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

\*****************************************************************************/


#ifndef VERSION

#define     VERSION     "PFM Software - tideEditor V1.3.7 - 2003-09-16"

#endif

/*

    This is where modification information should be added.

    Version 0.99
    Jan C. Depner
    08/16/02

    Prototype for testing.


    Version 1.00
    Jan C. Depner
    09/21/02

    First working version.


    Version 1.01
    Wade Ladner/Jan C. Depner
    12/09/02

    Modifications for Micro$oft Windoze (aaaaargh).


    Version 1.2
    Jan C. Depner
    02/27/03

    Separated out the map class.  Added separate color for subordinate 
    stations.


    Version 1.3
    David Flater
    2003-03-18

    Updated tideDialog per slack offsets fix 2003-03-18.


    Version 1.3.1
    David Flater
    2003-03-19

    Realized that version.h is only used for tideEditor and has
    nothing to do with build_tide_db or restore_tide_db.  Moved
    changelog for everything else into README.txt.

    Added version.h dependency to Makefile.


    Version 1.3.2
    David Flater
    2003-03-27

    Removed text about "simple" offsets from tideEditor on-line help.
    The "simplified" record format was abolished; see
    http://www.flaterco.com/xtide/tcd_notes.html


    Version 1.3.3
    Jan C. Depner
    2003-03-31

    Simple fix for 180 crossing error in nearest station search.


    Version 1.3.4
    David Flater
    2003-06-27

    Fixed a slack offset initialization in tideEditor that I
    overlooked back in March.


    Version 1.3.5
    Jan C. Depner
    2003-07-02

    When highlighting a subordinate station it would revert to red instead of
    blue when highlighting another station.  Nothing to see here, move along...


    Version 1.3.6
    Jan C. Depner
    2003-09-04

    Sort the constituents in the tide dialog so you can find things more
    easily.


    Version 1.3.7
    Jan C. Depner
    2003-09-16

    Added ability to print station data from the tide dialog.

*/

==> xtide_2.8.2.orig.tar.gz: xtide-2.8.2/tcd-utils/version.h <==

/*****************************************************************************\

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

\*****************************************************************************/


#ifndef VERSION

#define     VERSION     "PFM Software - tideEditor V1.3.10 - 2004-10-19"

#endif

/*

    This is where modification information should be added.

    Version 0.99
    Jan C. Depner
    08/16/02

    Prototype for testing.


    Version 1.00
    Jan C. Depner
    09/21/02

    First working version.


    Version 1.01
    Wade Ladner/Jan C. Depner
    12/09/02

    Modifications for Micro$oft Windoze (aaaaargh).


    Version 1.2
    Jan C. Depner
    02/27/03

    Separated out the map class.  Added separate color for subordinate 
    stations.


    Version 1.3
    David Flater
    2003-03-18

    Updated tideDialog per slack offsets fix 2003-03-18.


    Version 1.3.1
    David Flater
    2003-03-19

    Realized that version.h is only used for tideEditor and has
    nothing to do with build_tide_db or restore_tide_db.  Moved
    changelog for everything else into README.txt.

    Added version.h dependency to Makefile.


    Version 1.3.2
    David Flater
    2003-03-27

    Removed text about "simple" offsets from tideEditor on-line help.
    The "simplified" record format was abolished; see
    http://www.flaterco.com/xtide/tcd_notes.html


    Version 1.3.3
    Jan C. Depner
    2003-03-31

    Simple fix for 180 crossing error in nearest station search.


    Version 1.3.4
    David Flater
    2003-06-27

    Fixed a slack offset initialization in tideEditor that I
    overlooked back in March.


    Version 1.3.5
    Jan C. Depner
    2003-07-02

    When highlighting a subordinate station it would revert to red instead of
    blue when highlighting another station.  Nothing to see here, move along...


    Version 1.3.6
    Jan C. Depner
    2003-09-04

    Sort the constituents in the tide dialog so you can find things more
    easily.


    Version 1.3.7
    Jan C. Depner
    2003-09-16

    Added ability to print station data from the tide dialog.


    Version 1.3.8
    David Flater
    2004-10-05

    Fixed bad sscanf return value check in TideDialog::slotUpdateStation.


    Version 1.3.9
    David Flater
    2004-10-15

    Made minimum changes to make it run with libtcd 2.0 without
    COMPAT114.  Deleted fields no longer present, but did not add any
    new fields.  To do:  at least let reference stations have current
    directions.

    Made it compile cleanly under -Wall.


    Version 1.3.10
    David Flater
    2004-10-19

    Fixed two signed/unsigned conversions revealed by g++ -Wall -W
    -pedantic.  (N.B., left alone all the %lf formats in fixpos.cpp)
*/
